@@ -7,9 +7,9 @@ createTask <- function(project, package, taskname,
                        sponsor= getTaskSponsor(),
                        author = getTaskAuthor()) {
   # create paths
-  paths <- getTaskStructure()(project,package,taskname,sponsor)
+  #paths <- getTaskStructure()(project,package,taskname,sponsor)
   # retrieved dependencies loaded or attached
-  pkgs <- loadedNamespaces()
+  pkgs <- intersect(loadedNamespaces(),rownames(utils::installed.packages()))
   pkgsVersion <- sapply(pkgs, function(x) as.character(packageVersion(x)))
   pkgsVersionStr <- paste(names(pkgsVersion), pkgsVersion, sep = ":")
   sessionStr <- paste(R.version.string, pkgsVersionStr, collapse = "; ")
@@ -24,8 +24,8 @@ createTask <- function(project, package, taskname,
     date = format(Sys.time(),"%Y-%m-%d"),
     footer = sprintf("Copyright (c) %s %s - CONFIDENTIAL",sponsor,format(Sys.time(),"%Y")),
     version = "0.0",
-    dependencies = sessionStr,
-    paths = paths
+    dependencies = sessionStr
+    #paths = paths
   )
   class(task) <- c("D4TAlinkTask", class(task))
   return(task)
